@@ -3,7 +3,7 @@ import sympy
 import IPython
 
 DatosList = []
-Documento = ""
+Documento = []
 #https://widdowquinn.github.io/coding/update-pypi-package/
 
 #_print_Symbol
@@ -22,7 +22,7 @@ def Inicializar(n):
 
   DatosList = [[sympy.pi,3.14]]
   Orden = 8
-  Documento = ""
+  Documento = []
   return DatosList,Orden,Documento
 def search(symbolo):
   for c_element in DatosList:
@@ -70,9 +70,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     #texto = texto.replace("text", Estilo)
 
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-    print(Documento)
-    print(Documento + " /n"+str(texto))
-    Documento = str(Documento) + " /n"+str(texto)
+    Documento.append(texto)
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
 
@@ -92,7 +90,8 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     print(Documento)
     print(Documento + " /n"+str(texto))
-    Documento = str(Documento) + " /n"+str(texto)
+    #Documento += " /n" + str(texto)
+    Documento.append(texto)
 
 #def E(expr,color = "red"):
 #  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
